
For CMCC  APP记录用的

```angular2
使用说明:

import  WZCMCCAPPLOGGER;

使用方法:
1.安装 python -m pip install WZCMCCAPPLOGGER
2.
#WZCMCCAPPLOGGER.url="192.168.5.103:82" 默认
WZCMCCAPPLOGGER.InsertLog("[APPID]","[loginfo]");

url 可以选参数 可以输入 10.77.18.248:82 OA网段
192.168.5.103:82 内网网段
10.212.194.197:82 DCN网段



```